@@ -1,5 +1,6 @@
 from ua2.ajax import accept_ajax
 from celery.result import AsyncResult
+from celery.utils.encoding import safe_repr
 
 from ua2.celery.auth import auth_decorator
 
@@ -13,7 +14,10 @@ def task_status(request, task_id):
        - provide authorization decorator
     """
     result = AsyncResult(task_id)
-
+    task_result = result.result
+    if result.status == 'FAILURE':
+        task_result = safe_repr(result.result)
+        
     return {'task_id': task_id,
             'status': result.status,
-            'result': result.result}
+            'result': task_result}
